import greenfoot.*;


public class HealthBar extends Utilitati
{
    private int barWidth = 100; //latimea barii
    private int barHeight = 10; // inaltimea barii
    private int breakPercent = 20; // procentul la care bara se schimba
    private int breakValue = 20; // in tandem cu procentul
    private boolean usingBreakValue = false; //daca folosesc valoarea
    private boolean breakLow = true; // daca sunt cu viata pe low
    
    private Color backgroundColor = new Color(0, 0, 0, 0); //culoarea de fundal
    private Color textColor = Color.BLACK; // culoarea textului
    private Color safeColor = Color.GREEN; // culoarea de siguranta
    private Color dangerColor = Color.RED; // culoarea pe zona rosie

    private float fontSize = 18.0f; // marimea textului
    private int value = 0; // valoarea curenta a barii
    private int maximumValue = 0; // valoarea maxima
    private int minimumValue = 0; // valoarea minima
    private String referenceText = ""; // titlul barii
    private String unitOfMeasure = ""; // unitatea de masura
    private boolean showTextualUnits = true; // daca se afiseaza valoarea textuala
    
    
    public HealthBar(String refText, String unitType, int initValue, int maxValue)
    {
        referenceText = refText;
        unitOfMeasure = unitType;
        maximumValue = maxValue;
        add(initValue);
    }
    
    
    private void newImage()
    {
        int barValue = (int) (barWidth * (value - minimumValue) / (maximumValue - minimumValue));//iau valoarea barii
        GreenfootImage leftImg = new GreenfootImage(referenceText + " ", (int) fontSize, textColor, backgroundColor);//imaginea din stanga
        GreenfootImage rightImg = (showTextualUnits) ? new GreenfootImage(" " + value + " " + unitOfMeasure, (int) fontSize, textColor, backgroundColor) : new GreenfootImage(1, 1);//imaginea care se modifica dinamic
        int maxX = (leftImg.getWidth() > rightImg.getWidth()) ? leftImg.getWidth() : rightImg.getWidth();//x-ul maxim
        GreenfootImage barImg = new GreenfootImage(barWidth + 4, barHeight + 4);//imaginea barii
        barImg.setColor(backgroundColor);
        barImg.fill();
        barImg.setColor(textColor);
        barImg.drawRect(0, 0, barImg.getWidth() - 1, barImg.getHeight() - 1);//desenez imaginea
        if (value > minimumValue)
        {
            if (breakLow)
            {
                if (value > (usingBreakValue ? breakValue : (int) (breakPercent * (maximumValue - minimumValue) / 100 + minimumValue))) barImg.setColor(safeColor);//daca mai am viata, nu sunt inca in pericol
                else barImg.setColor(dangerColor);
            }
            else
            {
                if (value < (usingBreakValue ? breakValue : (int) (breakPercent * (maximumValue - minimumValue) / 100 + minimumValue))) barImg.setColor(safeColor);//daca mai am viata, nu sunt inca in pericol
                else barImg.setColor(dangerColor);
            }
            if (value == (usingBreakValue ? breakValue : (int) (breakPercent * (maximumValue - minimumValue) / 100 + minimumValue)))
            {
                int r = (int) ((safeColor.getRed() + dangerColor.getRed()) / 2);
                int g = (int) ((safeColor.getGreen() + dangerColor.getGreen()) / 2);
                int b = (int) ((safeColor.getBlue() + dangerColor.getBlue()) / 2);
                barImg.setColor(new Color(r, g, b));//schimb culoarea
            }
            barImg.fillRect(2, 2, barValue, barHeight);//pun culoarea
        }
        int sumX = 2 * maxX + barImg.getWidth();
        int maxY = 0;
        if (leftImg.getHeight() > maxY) maxY = leftImg.getHeight();
        if (barImg.getHeight() > maxY) maxY = barImg.getHeight();
        if (rightImg.getHeight() > maxY) maxY = rightImg.getHeight();
        GreenfootImage image = new GreenfootImage(sumX, maxY);
        image.setColor(backgroundColor);
        image.fill();//dau fill la imagine
        image.drawImage(leftImg, maxX - leftImg.getWidth(), (image.getHeight() - leftImg.getHeight()) / 2);
        image.drawImage(barImg, maxX, (image.getHeight() - barImg.getHeight()) / 2);
        image.drawImage(rightImg, maxX + barImg.getWidth(), (image.getHeight() - rightImg.getHeight()) / 2);
        setImage(image);
    }
    
    
    //metodele utilizate
    public void add(int amount)
    {
        value += amount;
        checkValue();
        newImage();
    }
    
    
    public void subtract(int amount)
    {
        value -= amount;
        checkValue();
        newImage();
    }
    
    private void checkValue()
    {
        if (value < minimumValue) value = minimumValue;
        if (value > maximumValue) value = maximumValue;
    }
    
    
    public int getValue() { return value; }
    
    
    public int getBarWidth() { return barWidth; }
 
    
    public int getBarHeight() { return barHeight; }
    
    
    public int getBreakPercent() { return breakPercent; } 
    
    
    public int getBreakValue() { return breakValue; } 
    
    
    public boolean getBreakLow() { return breakLow; }
    
    
    public Color getBackgroundColor() { return backgroundColor; }
    
    
    public Color getTextColor() { return textColor; }
    
    
    public Color getSafeColor() { return safeColor; }
    
    
    public Color getDangerColor() { return dangerColor; }
    
   
    public float getFontSize() { return fontSize; }
    
    
    public int getMaximumValue() { return maximumValue; }
    
   
    public int getMinimumValue() { return minimumValue; }
    
    
    public String getReferenceText() { return referenceText; }
    
    
    public String getUnitOfMeasure() { return unitOfMeasure; }
    
    
    public boolean getShowTextualUnits() { return showTextualUnits; }
    
    
    public void setValue(int val) { value = val; checkValue(); newImage(); }
    
    
    public void setBarWidth(int width) { if (width > 9) { barWidth = width; newImage(); } } //182
    
    
    public void setBarHeight(int height) { if (height > 1) { barHeight = height; newImage(); } } //17
    
    
    public void setBreakPercent(int percent) { if (percent >= 0 && percent <= 100) { breakPercent = percent; usingBreakValue = false; newImage(); } }
    
    
    public void setBreakValue(int brkVal) { if (brkVal >= minimumValue && brkVal <= maximumValue) {breakValue = brkVal; usingBreakValue = true; newImage(); } }
    
    
    public void setBreakLow(boolean lowBreak) { breakLow = lowBreak; newImage(); }
    
    
    public void setBackgroundColor(Color color) { backgroundColor = color; newImage(); }
    
    
    public void setTextColor(Color color) { textColor = color; newImage(); }
    
    
    public void setSafeColor(Color color) { safeColor = color; newImage(); }
    
    
    public void setDangerColor(Color color) { dangerColor = color; newImage(); }
    
    
    public void setFontSize(float size) { if (size > 7) { fontSize = size; newImage(); } }
    
    
    public void setMaximumValue(int maxVal) { if (maxVal > minimumValue) { maximumValue = maxVal; newImage(); } }
    
    
    public void setMinimumValue(int minVal) { if (minVal < maximumValue) { minimumValue = minVal; newImage(); } }
    
    
    public void setReferenceText(String refText) { referenceText = refText; newImage(); }
    
    
    public void setUnitOfMeasure(String uom) { unitOfMeasure = uom; newImage(); }
    
    
    public void setShowTextualUnits(boolean show) { showTextualUnits = show; newImage(); }
}